pub struct TestCase {
pub name: &'static str,
pub stream: Rc<dyn ElementaryStream>,
pub validators: Vec<Rc<dyn OutputValidator>>,
pub stream_options: Option<StreamOptions>,
}Expand description
A test cases describes a sequence of elementary stream chunks that should be fed into a codec server, and a set of validators to check the output. To pass, all validations must pass for all output from the stream.
Fields
name: &'static strstream: Rc<dyn ElementaryStream>validators: Vec<Rc<dyn OutputValidator>>stream_options: Option<StreamOptions>Auto Trait Implementations
impl Freeze for TestCase
impl !RefUnwindSafe for TestCase
impl !Send for TestCase
impl !Sync for TestCase
impl Unpin for TestCase
impl UnsafeUnpin for TestCase
impl !UnwindSafe for TestCase