pub struct TestSpec {
pub cases: Vec<TestCase>,
pub relation: CaseRelation,
pub stream_processor_factory: Rc<dyn StreamProcessorFactory>,
}Expand description
A test spec describes all the cases that will run and the circumstances in which they will run.
Fields
cases: Vec<TestCase>relation: CaseRelationstream_processor_factory: Rc<dyn StreamProcessorFactory>Implementations